@@ -44,6 +44,8 @@ def _run_read(
         configure.clear_loglevel(args[0])
 
         out = ffmpegprocess.run(*args, capture_log=True, **kwargs)
+        if show_log:
+            print(out.stderr)
         if out.returncode:
             raise FFmpegError(out.stderr)
 
@@ -73,12 +75,12 @@ def create(
     *args,
     progress=None,
     show_log=None,
-    aframes=None,
+    t_in=None,
     ar=None,
     ac=None,
     sample_fmt=None,
     af=None,
-    **kwargs
+    **kwargs,
 ):
     """Create audio data using an audio source filter
 
@@ -92,7 +94,17 @@ def create(
                      defaults to None (no show/capture)
                      Ignored if stream format must be retrieved automatically.
     :type show_log: bool, optional
-    :param \\**options: filter keyword arguments
+    :param t_in: duration of the video in seconds, defaults to None
+    :type t_in: float, optional
+    :param ar: sampling rate in samples/second, defaults to None
+    :type ar: int, optional
+    :param ac: number of channels, defaults to None
+    :type ac: int, optional
+    :param sample_fmt: sample format, defaults to None
+    :type sample_fmt: str, optional
+    :param af: additional filter, defaults to None
+    :type af: FilterGraph or str, optional
+    :param \\**options: FFmpeg options (see :doc:`options`)
     :type \\**options: dict, optional
     :return: audio data
     :rtype: numpy.ndarray
@@ -114,25 +126,25 @@ def create(
 
     """
 
-    # if duration is not None:
-    #     nb_samples = int(duration * sample_rate)
-    # elif nb_samples is not None:
-    #     duration = nb_samples / sample_rate
-    # else:
-    #     raise Exception("either duration or nb_samples must be specified")
-
     url, (ar_in, ac_in) = filter_utils.compose_source("audio", expr, *args, **kwargs)
 
     if sample_fmt is None:
         sample_fmt = "dbl"
 
+    # need_t = ("mandelbrot", "life")
+    # if t_in is None and any((expr.startswith(f) for f in need_t)):
+    #     raise ValueError(f"Some sources {need_t} must have t_in specified")
+
     ffmpeg_args = configure.empty()
-    configure.add_url(ffmpeg_args, "input", url, {"f": "lavfi"})
+    inopts = configure.add_url(ffmpeg_args, "input", url, {"f": "lavfi"})[1][1]
     outopts = configure.add_url(ffmpeg_args, "output", "-", {})[1][1]
 
+    if t_in:
+        inopts["t"] = t_in
+
     for k, v in zip(
-        ("frames:a", "ar", "ac", "sample_fmt", "filter:a"),
-        (aframes, ar or ar_in, ac or ac_in, sample_fmt, af),
+        ("ar", "ac", "sample_fmt", "filter:a"),
+        (ar or ar_in, ac or ac_in, sample_fmt, af),
     ):
         if v is not None:
             outopts[k] = v
@@ -158,7 +170,7 @@ def read(url, progress=None, show_log=None, **options):
                      defaults to None (no show/capture)
                      Ignored if stream format must be retrieved automatically.
     :type show_log: bool, optional
-    :param \\**options: other keyword options (see :doc:`options`)
+    :param \\**options: FFmpeg options, append '_in' for input option names (see :doc:`options`)
     :type \\**options: dict, optional
     :return: sample rate in samples/second and audio data matrix (timexchannel)
     :rtype: tuple(`float`, :py:class:`numpy.ndarray`)
@@ -201,7 +213,7 @@ def read(url, progress=None, show_log=None, **options):
     )
 
 
-def write(url, rate, data, progress=None, show_log=None, **options):
+def write(url, rate, data, progress=None, overwrite=None, show_log=None, **options):
     """Write a NumPy array to an audio file.
 
     :param url: URL of the audio file to write.
@@ -212,10 +224,13 @@ def write(url, rate, data, progress=None, show_log=None, **options):
     :type data: numpy.ndarray
     :param progress: progress callback function, defaults to None
     :type progress: callable object, optional
+    :param overwrite: True to overwrite if output url exists, defaults to None
+                      (auto-select)
+    :type overwrite: bool, optional
     :param show_log: True to show FFmpeg log messages on the console,
                      defaults to None (no show/capture)
     :type show_log: bool, optional
-    :param \\**options: other keyword options (see :doc:`options`)
+    :param \\**options: FFmpeg options, append '_in' for input option names (see :doc:`options`)
     :type \\**options: dict, optional
     :param data: A 1-D or 2-D NumPy array of either integer or float data-type.
     :type data: `numpy.ndarray`
@@ -237,6 +252,7 @@ def write(url, rate, data, progress=None, show_log=None, **options):
         input=data,
         stdout=stdout,
         progress=progress,
+        overwrite=overwrite,
         capture_log=False if show_log else None,
     )
 
@@ -252,8 +268,8 @@ def filter(expr, input_rate, input, progress=None, sample_fmt=None, **options):
     :type input: 1D or 2D numpy.ndarray
     :param progress: progress callback function, defaults to None
     :type progress: callable object, optional
-    :param **options: FFmpeg options, prepend 'input_' for input option names.
-    :type **options: dict
+    :param \\**options: FFmpeg options, append '_in' for input option names (see :doc:`options`)
+    :type \\**options: dict, optional
     :return: output sampling rate and data
     :rtype: tuple(int, numpy.ndarray)
 
