@@ -140,10 +140,7 @@ def compose(args, command="", shell_command=False):
     """
 
     def finalize_global(key, val):
-        if key == "overwrite":
-            key = "y" if val else "n"
-            val = None
-        elif key in ("filter_complex", "lavfi"):
+        if key in ("filter_complex", "lavfi"):
             val = filter_utils.compose(val)
         return key, val
 
@@ -452,7 +449,16 @@ class ProgressMonitor(_Thread):
                             if not m:
                                 continue
                             if m[1] != "progress":
-                                d[m[1]] = m[2]
+                                val = m[2].lstrip()
+                                try:
+                                    val = int(val)
+                                except:
+                                    try:
+                                        val = float(val)
+                                    except:
+                                        pass
+
+                                d[m[1]] = val
                             else:
                                 done = m[2] == "end"
                                 try:
@@ -487,6 +493,7 @@ def exec(
     ffmpeg_args,
     hide_banner=True,
     progress=None,
+    overwrite=None,
     capture_log=None,
     stdin=None,
     stdout=None,
@@ -502,6 +509,9 @@ def exec(
     :type hide_banner: bool, optional
     :param progress: progress monitor object, defaults to None
     :type progress: ProgressMonitor, optional
+    :param overwrite: True to overwrite if output url exists, defaults to None
+                      (auto-select)
+    :type overwrite: bool, optional
     :param capture_log: True to capture log messages on stderr, False to send
                         logs to console, defaults to None (no show/capture)
     :type capture_log: bool or None, optional
@@ -581,6 +591,16 @@ def exec(
         PIPE if capture_log else DEVNULL if capture_log is None else None
     )
 
+    # set y or n flags (overwrite)
+    gopts = ffmpeg_args["global_options"]
+    if not (gopts and ("y" in gopts or "n" in gopts)):
+        if gopts is None:
+            gopts = ffmpeg_args["global_options"] = {}
+        if overwrite is not None:
+            gopts["y" if overwrite else "n"] = None
+        elif inpipe == PIPE:
+            gopts["n"] = None
+
     args = compose(ffmpeg_args, command=_get_ffmpeg())
     _logging.debug(args)
 
